# panel4all

Functions for parsing results of surveys made by panel4all.co.il

## Installation 

    pip install panel4all

## Usage

See [example 1](example1/README.md) and [example 2](example2/README.md).
